==> edsteva-0.1.2.tar.gz: edsteva-0.1.2/README.md <==
<p align="center">
<b>DISCLAIMER: </b>EDS-TeVa is intended to be a module of <a href="https://github.com/aphp/EDS-Scikit">EDS-Scikit</a>
</p>

<div align="center">

<p align="center">
  <a href="https://aphp.github.io/edsteva/latest/"><img src="https://aphp.github.io/edsteva/latest/assets/logo/edsteva_logo_small.svg" alt="EDS-TeVa"></a>
</p>

# EDS-TeVa [![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/aphp/edsteva/HEAD?labpath=notebooks%2Fsynthetic_data.ipynb)

<p align="center">
<a href="https://aphp.github.io/edsteva/latest/" target="_blank">
    <img src="https://img.shields.io/github/workflow/status/aphp/edsteva/Documentation?label=docs&style=flat" alt="Documentation">
</a>
<a href="https://pypi.org/project/edsteva/" target="_blank">
    <img src="https://img.shields.io/pypi/v/edsteva?color=blue&style=flat" alt="PyPI">
</a>
<a href="https://codecov.io/github/aphp/edsteva?branch=main" target="_blank">
    <img src="https://codecov.io/github/aphp/edsteva/coverage.svg?branch=main" alt="Codecov">
</a>
<a href="https://github.com/psf/black" target="_blank">
    <img src="https://img.shields.io/badge/code%20style-black-000000.svg" alt="Black">
</a>
<a href="https://python-poetry.org/" target="_blank">
    <img src="https://img.shields.io/badge/reproducibility-poetry-blue" alt="Poetry">
</a>
<a href="https://www.python.org/" target="_blank">
    <img src="https://img.shields.io/badge/python-~3.7.1-brightgreen" alt="Supported Python versions">
</a>
</p>
</div>

**Documentation**: <a href="https://aphp.github.io/edsteva/latest/" target="_blank">https://aphp.github.io/edsteva/latest/</a>

**Source Code**: <a href="https://github.com/aphp/edsteva" target="_blank">https://github.com/aphp/edsteva</a>

---

EDS-TeVa provides a set of tools that aims at modeling the adoption over time and across space of the Electronic Health Records.

## Requirements
EDS-TeVa stands on the shoulders of [Spark 2.4](https://spark.apache.org/docs/2.4.8/index.html) which requires:

- Python ~3.7.1
- Java 8

## Installation

You can install EDS-TeVa through ``pip``:

```shell
pip install edsteva
```
We recommend pinning the library version in your projects, or use a strict package manager like [Poetry](https://python-poetry.org/).

```
pip install edsteva==0.1.2
```
## Example

A scientific paper is currently being written that describes extensively the use of the library on the study of pulmonary embolism of cancer patients.

## Contributing

Contributions are welcome, and they are greatly appreciated! Every little bit helps, and credit will always be given.

## Acknowledgement

We would like to thank [Assistance Publique – Hôpitaux de Paris](https://www.aphp.fr/) and [AP-HP Foundation](https://fondationrechercheaphp.fr/) for funding this project.

==> edsteva-0.1.3.tar.gz: edsteva-0.1.3/README.md <==
<p align="center">
<b>DISCLAIMER: </b>EDS-TeVa is intended to be a module of <a href="https://github.com/aphp/EDS-Scikit">EDS-Scikit</a>
</p>

<div align="center">

<p align="center">
  <a href="https://aphp.github.io/edsteva/latest/"><img src="https://aphp.github.io/edsteva/latest/assets/logo/edsteva_logo_small.svg" alt="EDS-TeVa"></a>
</p>

# EDS-TeVa [![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/aphp/edsteva/HEAD?labpath=notebooks%2Fsynthetic_data.ipynb)

<p align="center">
<a href="https://aphp.github.io/edsteva/latest/" target="_blank">
    <img src="https://img.shields.io/github/actions/workflow/status/aphp/edsteva/documentation.yaml?branch=main&label=docs&style=flat" alt="Documentation">
</a>
<a href="https://pypi.org/project/edsteva/" target="_blank">
    <img src="https://img.shields.io/pypi/v/edsteva?color=blue&style=flat" alt="PyPI">
</a>
<a href="https://codecov.io/github/aphp/edsteva?branch=main" target="_blank">
    <img src="https://codecov.io/github/aphp/edsteva/coverage.svg?branch=main" alt="Codecov">
</a>
<a href="https://github.com/psf/black" target="_blank">
    <img src="https://img.shields.io/badge/code%20style-black-000000.svg" alt="Black">
</a>
<a href="https://python-poetry.org/" target="_blank">
    <img src="https://img.shields.io/badge/reproducibility-poetry-blue" alt="Poetry">
</a>
<a href="https://www.python.org/" target="_blank">
    <img src="https://img.shields.io/badge/python-~3.7.1-brightgreen" alt="Supported Python versions">
</a>
</p>
</div>

**Documentation**: <a href="https://aphp.github.io/edsteva/latest/" target="_blank">https://aphp.github.io/edsteva/latest/</a>

**Source Code**: <a href="https://github.com/aphp/edsteva" target="_blank">https://github.com/aphp/edsteva</a>

---

EDS-TeVa provides a set of tools that aims at modeling the adoption over time and across space of the Electronic Health Records.

## Requirements
EDS-TeVa stands on the shoulders of [Spark 2.4](https://spark.apache.org/docs/2.4.8/index.html) which requires:

- Python ~3.7.1
- Java 8

## Installation

You can install EDS-TeVa through ``pip``:

```shell
pip install edsteva
```
We recommend pinning the library version in your projects, or use a strict package manager like [Poetry](https://python-poetry.org/).

```
pip install edsteva==0.1.3
```
## Example

A scientific paper is currently being written that describes extensively the use of the library on the study of pulmonary embolism of cancer patients.

## Contributing

Contributions are welcome, and they are greatly appreciated! Every little bit helps, and credit will always be given.

## Acknowledgement

We would like to thank [Assistance Publique – Hôpitaux de Paris](https://www.aphp.fr/) and [AP-HP Foundation](https://fondationrechercheaphp.fr/) for funding this project.
